summary refs log tree commit diff
path: root/pkgs/development/libraries/boost
diff options
context:
space:
mode:
authorAndrew Childs <lorne@cons.org.nz>2022-02-15 12:02:36 +0900
committerGitHub <noreply@github.com>2022-02-14 22:02:36 -0500
commit8668f940c5fc6163f1381e45765de74578a02453 (patch)
tree0f6fb359ffb901bc229796d4ec8a0e661dc6fe35 /pkgs/development/libraries/boost
parent76bbae8262049bc86252d8785318298445b18675 (diff)
downloadnixpkgs-8668f940c5fc6163f1381e45765de74578a02453.tar
nixpkgs-8668f940c5fc6163f1381e45765de74578a02453.tar.gz
nixpkgs-8668f940c5fc6163f1381e45765de74578a02453.tar.bz2
nixpkgs-8668f940c5fc6163f1381e45765de74578a02453.tar.lz
nixpkgs-8668f940c5fc6163f1381e45765de74578a02453.tar.xz
nixpkgs-8668f940c5fc6163f1381e45765de74578a02453.tar.zst
nixpkgs-8668f940c5fc6163f1381e45765de74578a02453.zip
boost: refine assertion requiring pth support in clang (#159990)
The pth feature was only used by boost's build with clang on linux,
and should not prevent building on darwin.
Diffstat (limited to 'pkgs/development/libraries/boost')
-rw-r--r--pkgs/development/libraries/boost/generic.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/development/libraries/boost/generic.nix b/pkgs/development/libraries/boost/generic.nix
index 6358df1a555..49069303570 100644
--- a/pkgs/development/libraries/boost/generic.nix
+++ b/pkgs/development/libraries/boost/generic.nix
@@ -31,8 +31,8 @@ assert enableShared || enableStatic;
 assert enablePython -> stdenv.hostPlatform == stdenv.buildPlatform;
 assert enableNumpy -> enablePython;
 
-# Boost <1.69 can't be build with clang >8, because pth was removed
-assert with lib; ((toolset == "clang" && !(versionOlder stdenv.cc.version "8.0.0")) -> !(versionOlder version "1.69"));
+# Boost <1.69 can't be built on linux with clang >8, because pth was removed
+assert with lib; ((stdenv.isLinux && toolset == "clang" && !(versionOlder stdenv.cc.version "8.0.0")) -> !(versionOlder version "1.69"));
 
 with lib;
 let